polyfemos.front.colors — polyfemos 0.3.29 documentation

# polyfemos.front.colors

Contains all color values for polyfemos

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.front.colors.` `get_color_styles`()
  Return type

    str

  Returns

    css styles consisting of color variables

`polyfemos.front.colors.` `render_colors`(func_)
  Parameters

    func_ (func) – `render_template()`

  Return type

    func

  Returns

    decorated function